@@ -1,31 +1,31 @@
 package MooseX::MethodAttributes::Role::Meta::Map;
-BEGIN {
-  $MooseX::MethodAttributes::Role::Meta::Map::AUTHORITY = 'cpan:FLORA';
-}
-{
-  $MooseX::MethodAttributes::Role::Meta::Map::VERSION = '0.28';
-}
 # ABSTRACT: generic role for storing code attributes used by classes and roles with attributes
 
-use Moose::Role;
-use MooseX::Types::Moose 0.20 qw/HashRef ArrayRef Str Int/;
+our $VERSION = '0.32';
 
-use namespace::clean -except => 'meta';
+use Moose::Role;
+
+use namespace::autoclean;
 
 has _method_attribute_map => (
     is        => 'ro',
-    isa       => HashRef[ArrayRef[Str]],
+    isa       => 'HashRef[ArrayRef[Str]]',
     lazy      => 1,
     default   => sub { +{} },
 );
 
 has _method_attribute_list => (
     is      => 'ro',
-    isa     => ArrayRef[Int],
+    isa     => 'ArrayRef[Int]',
     lazy    => 1,
     default => sub { [] },
 );
 
+#pod =method register_method_attributes ($code, $attrs)
+#pod
+#pod Register a list of attributes for a code reference.
+#pod
+#pod =cut
 
 sub register_method_attributes {
     my ($self, $code, $attrs) = @_;
@@ -34,6 +34,11 @@ sub register_method_attributes {
     return;
 }
 
+#pod =method get_method_attributes ($code)
+#pod
+#pod Get a list of attributes associated with a coderef.
+#pod
+#pod =cut
 
 sub get_method_attributes {
     my ($self, $code) = @_;
@@ -46,12 +51,16 @@ __END__
 
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
 MooseX::MethodAttributes::Role::Meta::Map - generic role for storing code attributes used by classes and roles with attributes
 
+=head1 VERSION
+
+version 0.32
+
 =head1 METHODS
 
 =head2 register_method_attributes ($code, $attrs)
@@ -62,6 +71,17 @@ Register a list of attributes for a code reference.
 
 Get a list of attributes associated with a coderef.
 
+=head1 SUPPORT
+
+Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=MooseX-MethodAttributes>
+(or L<bug-MooseX-MethodAttributes@rt.cpan.org|mailto:bug-MooseX-MethodAttributes@rt.cpan.org>).
+
+There is also a mailing list available for users of this distribution, at
+L<http://lists.perl.org/list/moose.html>.
+
+There is also an irc channel available for users of this distribution, at
+L<C<#moose> on C<irc.perl.org>|irc://irc.perl.org/#moose>.
+
 =head1 AUTHORS
 
 =over 4
@@ -76,9 +96,9 @@ Tomas Doran <bobtfish@bobtfish.net>
 
 =back
 
-=head1 COPYRIGHT AND LICENSE
+=head1 COPYRIGHT AND LICENCE
 
-This software is copyright (c) 2012 by Florian Ragwitz.
+This software is copyright (c) 2009 by Florian Ragwitz.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
