@@ -3,7 +3,7 @@ use Moose;
 # FIXME - This should not have to be here.
 use MooseX::MethodAttributes;
 
-use namespace::clean -except => 'meta';
+use namespace::autoclean;
 
 with 'RoleWithAttributes';
 
